---
title: Tutorials
category: Tutorials
permalink: /tutorials/index.html
order: 1
---

## Research Software Encyclopedia Tutorials

These tutorials will help to walk you through creating a parser, interacting
with the `rseng/software` repository, or creating your own research software
encyclopedia.

 - [Python](python/) interactive terminal to interact with a research software encyclopedia client.
 - [Annotation](annotation/) of the [rseng/software](https://github.com/rseng/software) database.

If you want to request or suggest a tutorial, please [open an issue](https://github.com/{{ site.repo }}/issues).
